==> slumber-3.1.3.tar.gz: slumber-3.1.3/docs/src/SUMMARY.md <==
# Summary

- [Introduction](./introduction.md)
- [Install](./install.md)
- [Getting Started](./getting_started.md)

# User Guide

- [Key Concepts](./user_guide/key_concepts.md)
- [Terminal User Interface (TUI)](./user_guide/tui/index.md)
  - [In-App Editing & File Viewing](./user_guide/tui/editor.md)
  - [Data Filtering & Querying](./user_guide/tui/filter_query.md)
- [Command Line Interface (CLI)](./user_guide/cli.md)
- [Templates](./user_guide/templates/index.md)
  - [Chains - Complex Template Values](./user_guide/templates/chains.md)
  - [Data Extraction via JSONPath](./user_guide/templates/selector.md)
- [Collection Reuse & Inheritance](./user_guide/inheritance.md)
- [Importing External Collections](./user_guide/import.md)
- [Database & Persistence](./user_guide/database.md)

# CLI Commands

- [Subcommands](./cli/subcommands.md)
- [Examples](./cli/examples.md)

# API Reference

- [Request Collection](./api/request_collection/index.md)
  - [Profile](./api/request_collection/profile.md)
  - [Template](./api/request_collection/template.md)
  - [Request Recipe](./api/request_collection/request_recipe.md)
    - [Query Parameters](./api/request_collection/query_parameters.md)
    - [Authentication](./api/request_collection/authentication.md)
    - [Recipe Body](./api/request_collection/recipe_body.md)
  - [Chain](./api/request_collection/chain.md)
  - [Chain Source](./api/request_collection/chain_source.md)
  - [Content Type](./api/request_collection/content_type.md)
- [Configuration](./api/configuration/index.md)
  - [Input Bindings](./api/configuration/input_bindings.md)
  - [MIME Maps](./api/configuration/mime.md)
  - [Theme](./api/configuration/theme.md)

# Integration

- [Neovim Integration](./integration/neovim-integration.md)

# Troubleshooting

- [Logs](./troubleshooting/logs.md)
- [Lost Request History](./troubleshooting/lost_history.md)
- [Shell Completions](./troubleshooting/shell_completions.md)
- [TLS Certificate Errors](./troubleshooting/tls.md)

==> slumber-3.4.0.tar.gz: slumber-3.4.0/docs/src/SUMMARY.md <==
# Summary

- [Introduction](./introduction.md)
- [Install](./install.md)
- [Getting Started](./getting_started.md)

# User Guide

- [Key Concepts](./user_guide/key_concepts.md)
- [Terminal User Interface (TUI)](./user_guide/tui/index.md)
  - [In-App Editing & File Viewing](./user_guide/tui/editor.md)
  - [Data Filtering & Querying](./user_guide/tui/filter_query.md)
- [Command Line Interface (CLI)](./user_guide/cli/index.md)
  - [Subcommands](./user_guide/cli/subcommands.md)
- [Templates](./user_guide/templates/index.md)
  - [Chains - Complex Template Values](./user_guide/templates/chains.md)
  - [Data Extraction via JSONPath](./user_guide/templates/selector.md)
- [Collection Reuse & Inheritance](./user_guide/inheritance.md)
- [Importing External Collections](./user_guide/import.md)
- [Database & Persistence](./user_guide/database.md)

# API Reference

- [Request Collection](./api/request_collection/index.md)
  - [Profile](./api/request_collection/profile.md)
  - [Template](./api/request_collection/template.md)
  - [Request Recipe](./api/request_collection/request_recipe.md)
    - [Query Parameters](./api/request_collection/query_parameters.md)
    - [Authentication](./api/request_collection/authentication.md)
    - [Recipe Body](./api/request_collection/recipe_body.md)
  - [Chain](./api/request_collection/chain.md)
  - [Chain Source](./api/request_collection/chain_source.md)
  - [Content Type](./api/request_collection/content_type.md)
- [Configuration](./api/configuration/index.md)
  - [Input Bindings](./api/configuration/input_bindings.md)
  - [MIME Maps](./api/configuration/mime.md)
  - [Theme](./api/configuration/theme.md)

# Integration

- [Neovim Integration](./integration/neovim-integration.md)

# Troubleshooting

- [Logs](./troubleshooting/logs.md)
- [Lost Request History](./troubleshooting/lost_history.md)
- [TLS Certificate Errors](./troubleshooting/tls.md)

# Other

- [Changelog](./changelog.md)
